Learn R Programming

LEdecomp (version 1.0.4)

lx_to_dx: Calculate the lifetable death distribution

Description

Minus the decumulation of the survival curve gives the death distribution. Or the element-wise product of lx and the conditional death probabilities qx gives the same thing.

Usage

lx_to_dx(lx)

Value

numeric vector of dx values

Arguments

lx

numeric vector of lifetable survivors at exact age x