sen_arriaga_sym_instantaneous2: Estimate sensitivity of life expectancy for a set of mortality rates by perturbing in the log space.
Description
This is a second approach for estimating the sensitivity for a single set of rates. Here, rather than directly expanding and contracting rates to convert mx into mx1 and mx2 we instead shift the logged mortality rates up and down by the factor perturb = h. Specifically:
$$m_{x}^{1} = e^{\ln\left(m_x\right) + h}$$
$$m_{x}^{2} = e^{\ln\left(m_x\right) - h}$$