Learn R Programming

LEdecomp (version 1.0.4)

sen_lopez_ruzicka_sym_instantaneous2: Log-scale instantaneous sensitivity via symmetrical Lopez-Ruzicka decomposition

Description

Estimates the instantaneous sensitivity of life expectancy using symmetric perturbations in log-scale mortality rates, based on the Lopez-Ruzicka decomposition.

Specifically, the function constructs: $$m_{x}^{1} = \exp(\log m_x + h)$$ $$m_{x}^{2} = \exp(\log m_x - h)$$ and applies sen_lopez_ruzicka_sym(mx1, mx2, ...) to the result.

Usage

sen_lopez_ruzicka_sym_instantaneous2(
  mx,
  age = 0:(length(mx) - 1),
  nx = rep(1, length(mx)),
  sex = "t",
  perturb = 1e-06,
  closeout = TRUE
)

Value

numeric vector of sensitivity of life expectancy to perturbations in mx.

Arguments

mx

Numeric vector of mortality rates (central death rates).

age

integer vector of the lower bound of each age group (currently only single ages supported)

nx

integer vector of age intervals, default 1.

sex

Character; "m" for male, "f" for female, or "t" for total.

perturb

Numeric; a small constant determining the perturbation size (default 1e-6).

closeout

logical. Default TRUE. Shall we use the HMD Method Protocol to close out the ax and qx values? See details.

Details

This method gives results equivalent to sen_lopez_ruzicka_sym_instantaneous() and sen_arriaga_sym_instantaneous2() and is preferred when working with log-transformed mortality schedules.

See Also

sen_lopez_ruzicka_sym, sen_lopez_ruzicka_sym_instantaneous, sen_arriaga_sym_instantaneous2

Examples

Run this code
a <- 0.001
b <- 0.07
x <- 0:100
mx <- a * exp(x * b)
s <- sen_lopez_ruzicka_sym_instantaneous2(mx, age = x)
# \donttest{
plot(x, s, type = "l")
# }

Run the code above in your browser using DataLab