The survival curve is calculated as the cumulative product of the conditional survival probabilities, which are the complement of conditional death probabilities, qx, except we take care to start with a clean 1. This function no radix option. lx with a radix of 1 can be interpreted as the probability of surviving from birth to age x.
qx_to_lx(qx, radix = 1)numeric vector of lx values
numeric vector of conditional death probabilities
initial lifetable cohort size, $l(0)$. Default 1.