Estimates the sensitivity of life expectancy to small changes in age-specific mortality rates using the symmetrical Arriaga decomposition. This is done by applying a small multiplicative perturbation to the input mortality rates and using the symmetrical sensitivity function sen_arriaga_sym().
Specifically, the function constructs:
$$m_{x}^{1} = m_x \cdot \left(\frac{1}{1 - h}\right)$$
$$m_{x}^{2} = m_x \cdot (1 - h)$$
and applies sen_arriaga_sym(mx1, mx2, ...) to the result.