Estimates the sensitivity of life expectancy to small changes in mortality rates using the Chandrasekaran III decomposition and log-transformed perturbations. The method perturbs mx up and down in log space and averages the directional sensitivities to approximate the derivative.
Specifically:
$$m_x^{1} = \exp(\ln m_x + h)$$
$$m_x^{2} = \exp(\ln m_x - h)$$
and applies sen_chandrasekaran_III(mx1, mx2, ...) and sen_chandrasekaran_III(mx2, mx1, ...),
returning their average.