Estimates the sensitivity of life expectancy to small changes in mortality rates using the Chandrasekaran II decomposition. This variant perturbs the mortality rates in log space, creating two versions of mx by adding and subtracting a small constant to log(mx), then exponentiating.
Specifically:
$$m_{x}^{1} = \exp\left( \ln m_x + h \right)$$
$$m_{x}^{2} = \exp\left( \ln m_x - h \right)$$
and applies sen_chandrasekaran_II(mx1, mx2, ...) to the result.