Estimates the sensitivity of life expectancy to small changes in mortality rates using the Lopez-Ruzicka decomposition. This is done by perturbing the input mortality rates up and down by a small factor and averaging the resulting directional sensitivities to approximate a symmetric derivative.
Specifically:
$$m_x^{1} = m_x \cdot \left( \frac{1}{1 - h} \right)$$
$$m_x^{2} = m_x \cdot (1 - h)$$
and applies sen_lopez_ruzicka(mx1, mx2, ...) and sen_lopez_ruzicka(mx2, mx1, ...),
returning their average.