Estimates the sensitivity of life expectancy to small changes in mortality rates using the Lopez-Ruzicka decomposition and log-space perturbation. This is done by shifting the log of the input mortality rates up and down by a small constant, then exponentiating, and computing the average directional sensitivity.
Specifically:
$$m_x^{1} = \exp(\ln m_x + h)$$
$$m_x^{2} = \exp(\ln m_x - h)$$
and applies sen_lopez_ruzicka(mx1, mx2, ...) and sen_lopez_ruzicka(mx2, mx1, ...),
returning their average.