Estimates the instantaneous sensitivity of life expectancy to small proportional changes in mortality rates, using the symmetrical Lopez-Ruzicka decomposition. This implementation perturbs the rates up and down around a central value and applies the symmetrical decomposition to the result.
Specifically, the function constructs:
$$m_{x}^{1} = m_x \cdot \left(\frac{1}{1 - h}\right)$$
$$m_{x}^{2} = m_x \cdot (1 - h)$$
and applies sen_lopez_ruzicka_sym(mx1, mx2, ...) to the result.